# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding field 'WebCounter.site'
        db.add_column('asv_seo_webcounter', 'site', self.gf('django.db.models.fields.related.ForeignKey')(default=1, to=orm['sites.Site']), keep_default=False)

        # Deleting field 'AnalPerm.site'
        db.delete_column('asv_seo_analperm', 'site_id')


    def backwards(self, orm):
        
        # Deleting field 'WebCounter.site'
        db.delete_column('asv_seo_webcounter', 'site_id')

        # User chose to not deal with backwards NULL issues for 'AnalPerm.site'
        raise RuntimeError("Cannot reverse this migration. 'AnalPerm.site' and its values cannot be restored.")


    models = {
        'asv_seo.analperm': {
            'Meta': {'ordering': "(u'system', u'name', u'de')", 'object_name': 'AnalPerm'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '512', 'db_index': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '512', 'blank': 'True'}),
            'system': ('django.db.models.fields.SlugField', [], {'max_length': '32', 'db_index': 'True'})
        },
        'asv_seo.seo': {
            'Meta': {'ordering': "(u'content_type', u'de')", 'object_name': 'SEO'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description_en': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'description_ru': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords_en': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'keywords_ru': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'title_en': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'}),
            'title_ru': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'asv_seo.seo4articles': {
            'Meta': {'ordering': "(u'content_type', u'de')", 'object_name': 'SEO4articles'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'lang': ('django.db.models.fields.CharField', [], {'default': "u'ru'", 'max_length': '2', 'blank': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'asv_seo.webcounter': {
            'Meta': {'ordering': "(u'site', u'lm')", 'object_name': 'WebCounter'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'code': ('django.db.models.fields.TextField', [], {}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sites.Site']"})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['asv_seo']



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

# temporary simple cache :(
class _AS_Cache(object):
    _cache = {}
    def add(self, host, site):
        rv = True
        t = self._cache.get(host,False)
        if t:
            return False
        self._cache[host] = site
        return True
    def remove(self,host):
        try:
            del self._cache[host]
            return True
        except KeyError:
            return False
    def get(self,host):
        return self._cache.get(host,False)
    def list(self):
        l = self._cache.keys()
        l.sort()
        return list((i,self._cache[i]) for i in l)

AScache = _AS_Cache()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.http import HttpResponse, HttpResponseNotFound
from asv_seo.models import *
from asv_seo.utils import GetSite

def Yandex(request, K='', **kwargs):
    h1 = '<h1>Page not found</h1>'
    #site = GetSite(request)
    #if not site:
    #    return HttpResponseNotFound(h1)
    try:
        #A = AnalPerm.objects.get(active=True, site=site.id, key=K)
        A = AnalPerm.objects.get(active=True, key=K)
    except AnalPerm.DoesNotExist:
        return HttpResponseNotFound(h1)
    return HttpResponse('{}'.format(A.key), content_type='text/plain')

def GetRobotsTxt(request, *args, **kwargs):
    h1 = '<h1>Page not found</h1>'
    site = GetSite(request)
    if not site:
        return HttpResponseNotFound(h1)
    try:
        R = RobotsTxt.objects.get(active=True, site=site.id)
    except RobotsTxt.DoesNotExist:
        return HttpResponseNotFound(h1)
    return HttpResponse('{}'.format(R.code), content_type='text/plain')




# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.conf import settings
from django.db import models
from django.db.models.signals import *
from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType
from django.contrib.sites.models import Site
from django.core.exceptions import *

#from mptt.models import MPTTModel
#import re

#---------------------------------------------------------------
#---------------------------------------------------------------
class SEO(models.Model):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object=generic.GenericForeignKey('content_type','object_id')
    #
    title_en   =models.CharField(blank=True, max_length=128, help_text='заголовок английской страницы')
    title_ru   =models.CharField(blank=True, max_length=128, help_text='заголовок русской страницы')
    keywords_en=models.TextField(blank=True, help_text='введите английские ключевые слова для страницы через запятую.')
    keywords_ru=models.TextField(blank=True, help_text='введите русские ключевые слова для страницы через запятую.')
    description_en=models.TextField(blank=True, help_text='опишите в 2-3 фразы о чем эта страница на английском языке')
    description_ru=models.TextField(blank=True, help_text='опишите в 2-3 фразы о чем эта страница на русском языке')
    de     = models.DateTimeField(auto_now_add=True)
    lm     = models.DateTimeField(auto_now=True)
    #----------
    def __unicode__(self):
        rv = self.title_ru if self.title_ru else self.title_en
        return rv
    class Meta:
        ordering = ('content_type', 'de')
        #unique_together = ('tree_id','level','slug')
        verbose_name='SEO'
        verbose_name_plural='SEO'
#---------------------------------------------------------------
#---------------------------------------------------------------
class SEO4articles(models.Model):
    content_type = models.ForeignKey(ContentType)
    object_id = models.PositiveIntegerField()
    content_object=generic.GenericForeignKey('content_type','object_id')
    #
    lang       =models.CharField(max_length=2, default='ru', verbose_name='язык', blank=True, editable=False)
    title      =models.CharField(blank=True, max_length=128)
    keywords   =models.TextField(blank=True, help_text='введите через запятую ключевые слова для страницы.')
    description=models.TextField(blank=True, help_text='опишите в 2-3 фразы о чем эта страница')
    de     = models.DateTimeField(auto_now_add=True)
    lm     = models.DateTimeField(auto_now=True)
    #----------
    def get_document(self):
        return self.content_object
    def __unicode__(self):
        rv = '[{}] {}'.format(self.lang, self.title)
        return rv
    def delete(self, **kwargs):
        try:
            # update Djapian's index, if it is!
            self.__class__.indexer.delete(self)
        except Exception as e:
            if settings.DEBUG:
                print('asv_seo__SEO4articles[{}].delete::{}'.format(self.id,e))
        super(SEO4articles, self).delete(**kwargs)
    def save(self, **kwargs):
        super(SEO4articles, self).save(**kwargs)
        try:
            # update Djapian's index, if it is!
            self.__class__.indexer.update()
        except Exception as e:
            if settings.DEBUG:
                print('asv_seo__SEO4articles[{}].save::{}'.format(self.id,e))
    #
    class Meta:
        ordering = ('content_type', 'de')
        #unique_together = ('tree_id','level','slug')
        verbose_name='SEO'
        verbose_name_plural='SEO'
#---------------------------------------------------------------
#---------------------------------------------------------------
class AnalPerm(models.Model):
    _analsystem_choices = (
        ('YANDEX',   'Yandex'),
        ('GOOGLE', 'Google'),
        )
    active=models.BooleanField(default=True)
    system=models.SlugField(max_length=32, choices=_analsystem_choices, verbose_name='в системе')
    key   =models.SlugField(max_length=512, unique=True, db_index=True)
    name  =models.CharField(max_length=512, blank=True)
    de    = models.DateTimeField(auto_now_add=True)
    lm    = models.DateTimeField(auto_now=True)

    def __unicode__(self):
        a = self.name or self.key
        return '{}: {}'.format(self.system, a)

    def save(self, **kwargs):
        if self.key.startswith('yandex_') or self.key.endswith('.txt'):
            q1=self.key.find('_')
            q1 = q1 if q1 >0 else 0
            q2=self.key.find('.')
            q2 = q2 if q2 >0 else 0

            if q1 and q2:
                self.key = self.key[q1+1:q2]
            elif q1:
                self.key = self.key[q1+1:]
            elif q2:
                self.key = self.key[:q2]
        super(AnalPerm, self).save(**kwargs)

    class Meta:
        ordering = ('system', 'name', 'de')
        verbose_name='авторизация в системе аналитики'
        verbose_name_plural='авторизации в системе аналитики'
#---------------------------------------------------------------
#---------------------------------------------------------------
class WebCounter(models.Model):
    active= models.BooleanField(default=True)
    site  = models.ForeignKey(Site)
    name  = models.CharField(max_length=128, blank=True)
    code  = models.TextField(help_text='Введите код счетчика.')
    de    = models.DateTimeField(auto_now_add=True)
    lm    = models.DateTimeField(auto_now=True)

    def __unicode__(self):
        a = self.name or 'Unnamed counter: {}'.format(de)
        return a

    #def save(self, **kwargs):
    #    super(WebCounter, self).save(**kwargs)

    class Meta:
        ordering = ('site', 'lm')
        verbose_name='код счетчика'
        verbose_name_plural='коды счетчиков'
#---------------------------------------------------------------
#---------------------------------------------------------------
class RobotsTxt(models.Model):
    active= models.BooleanField(default=True)
    site  = models.ForeignKey(Site)
    code  = models.TextField(help_text='тело файла robots.txt')
    de    = models.DateTimeField(auto_now_add=True)
    lm    = models.DateTimeField(auto_now=True)

    def __unicode__(self):
        return 'robots.txt for site {}'.format(self.site)

    #def save(self, **kwargs):
    #    super(WebCounter, self).save(**kwargs)

    class Meta:
        ordering = ('site', 'lm')
        verbose_name='файл robots.txt'
        verbose_name_plural='файлы robots.txt'
#---------------------------------------------------------------
#---------------------------------------------------------------



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'SEO'
        db.create_table('asv_seo_seo', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('title_en', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('title_ru', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('keywords_en', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('keywords_ru', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('description_en', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('description_ru', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('de', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('lm', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('asv_seo', ['SEO'])

        # Adding model 'SEO4articles'
        db.create_table('asv_seo_seo4articles', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('lang', self.gf('django.db.models.fields.CharField')(default=u'ru', max_length=2, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('keywords', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('de', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('lm', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('asv_seo', ['SEO4articles'])

        # Adding model 'AnalPerm'
        db.create_table('asv_seo_analperm', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('system', self.gf('django.db.models.fields.SlugField')(max_length=32, db_index=True)),
            ('key', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=512, db_index=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=512, blank=True)),
        ))
        db.send_create_signal('asv_seo', ['AnalPerm'])

        # Adding model 'WebCounter'
        db.create_table('asv_seo_webcounter', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128, blank=True)),
            ('code', self.gf('django.db.models.fields.TextField')()),
            ('de', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('lm', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('asv_seo', ['WebCounter'])


    def backwards(self, orm):
        
        # Deleting model 'SEO'
        db.delete_table('asv_seo_seo')

        # Deleting model 'SEO4articles'
        db.delete_table('asv_seo_seo4articles')

        # Deleting model 'AnalPerm'
        db.delete_table('asv_seo_analperm')

        # Deleting model 'WebCounter'
        db.delete_table('asv_seo_webcounter')


    models = {
        'asv_seo.analperm': {
            'Meta': {'ordering': "(u'system', u'name')", 'object_name': 'AnalPerm'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '512', 'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '512', 'blank': 'True'}),
            'system': ('django.db.models.fields.SlugField', [], {'max_length': '32', 'db_index': 'True'})
        },
        'asv_seo.seo': {
            'Meta': {'ordering': "(u'content_type', u'de')", 'object_name': 'SEO'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description_en': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'description_ru': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords_en': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'keywords_ru': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'title_en': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'}),
            'title_ru': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'asv_seo.seo4articles': {
            'Meta': {'ordering': "(u'content_type', u'de')", 'object_name': 'SEO4articles'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'lang': ('django.db.models.fields.CharField', [], {'default': "u'ru'", 'max_length': '2', 'blank': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'asv_seo.webcounter': {
            'Meta': {'ordering': "(u'lm',)", 'object_name': 'WebCounter'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'code': ('django.db.models.fields.TextField', [], {}),
            'de': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'lm': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'blank': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['asv_seo']



# -*- coding: utf-8 -*-
try:
    from django.conf.urls import patterns, url
except ImportError:
    # for Django < 1.4
    from django.conf.urls.defaults import patterns, url
from asv_seo.views import *

urlpatterns = patterns('',
    url(r'^yandex_(?P<K>.*).txt$', Yandex),
    url(r'^robots.txt$', GetRobotsTxt),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.contrib.sites.models import Site
from django.dispatch import receiver
from asv_seo.models import *
from asv_seo.cache import AScache

def GetSite(request):
    h = request.get_host()
    a = h.find(':')
    if a >0:
        h = h[:a]
    ss = AScache.get(h)
    if ss:
        return ss
    try:
        ss = Site.objects.get(domain=h)
        AScache.add(h,ss)
        return ss
    except MultipleObjectsReturned:
        ss = Site.objects.filter(domain=h).order_by('pk')[0]
        AScache.add(h,ss)
        return ss
    except ObjectDoesNotExist:
        pass
    sites = []
    ss = Site.objects.all().order_by('pk')
    for i in ss:
        if i.domain[0] == '.' and (h.endswith(i.domain) or '.{}'.format(h) == i.domain):
            sites.append(i)
    y = len(sites)
    k = None
    if y < 1:
        pass
    elif y == 1:
        k = sites[0]
        AScache.add(h,k)
    else:
        y = 0
        for i in sites:
            t = len(i.domain)
            if  t > y:
                k = i
                y = t
        AScache.add(h,k)
    return k

def remove_recs_from_cache(sender, **kwargs):
    sss = kwargs.get('instance')
    if sss:
        try:
            ss = sender.objects.get(pk=sss.pk)
            for a in AScache.list():
                if a[1]==ss:
                    AScache.remove(a[0])
        except sender.DoesNotExist:
            pass
            #

@receiver(pre_save, sender=Site)
def modify_site_rec(sender, **kwargs):
    remove_recs_from_cache(sender, **kwargs)

@receiver(pre_delete, sender=Site)
def remove_site_rec(sender, **kwargs):
    remove_recs_from_cache(sender, **kwargs)
